pub enum NotificationResponse {
None,
ActionButton(String),
CloseButton(String),
Click,
Reply(String),
}Expand description
Response from the Notification
Variants
None
No interaction has occured
ActionButton(String)
User clicked on an action button with the given name
CloseButton(String)
User clicked on the close button with the given name
Click
User clicked the notification directly
Reply(String)
User submitted text to the input text field